# ooi: OpenStack OCCI Interface

ooi is an implementation the Open Grid Forum's
[Open Cloud Computing Interface (OCCI)](http://www.occi-wg.org)
for [OpenStack](http://www.openstack.org).

The documentation for OOI is available at
    http://ooi.readthedocs.org/en/latest

In the unfortunate event that bugs are discovered, they should
be reported to the bug tracker available at:

   http://bugs.launchpad.net/ooi

Developers wishing to work on the ooi project should always base their work on
the latest ooi code, available from the master GIT repository at:

   https://git.openstack.org/cgit/openstack/ooi
